@@ -78,7 +78,7 @@ public class ListSourcesAction extends AbstractSubscribeSourcesAction {
 
     private static final String[] FIELDS = new String[] { "id", "displayName", "icon", "module", "formDescription" };
 
-    private static final Set<String> IGNOREES = Collections.unmodifiableSet(new HashSet<String>(Arrays.asList("com.openexchange.subscribe.crawler.facebook", "com.openexchange.subscribe.crawler.gmx")));
+    private static final Set<String> IGNOREES = Collections.unmodifiableSet(new HashSet<String>(Arrays.asList("com.openexchange.subscribe.crawler.gmx")));
 
     @Override
     public AJAXRequestResult perform(SubscribeRequest subscribeRequest) throws OXException {
@@ -87,7 +87,7 @@ public class ListSourcesAction extends AbstractSubscribeSourcesAction {
         final List<SubscriptionSource> sources = new ArrayList<SubscriptionSource>(getAvailableSources(subscribeRequest.getServerSession()).getSources(module));
         for (final Iterator<SubscriptionSource> iterator = sources.iterator(); iterator.hasNext();) {
             final SubscriptionSource subscriptionSource = iterator.next();
-            if (IGNOREES.contains(subscriptionSource.getId())) {
+            if (IGNOREES.contains(subscriptionSource.getId()) || false == subscriptionSource.getSubscribeService().isCreateModifyEnabled()) {
                 iterator.remove();
             }
         }
